@@ -463,6 +463,13 @@ class google_routesearch(h_UI_helper, math_helper):
             return m[5]
         else:
             return m[2]
+    
+    def get_point(self, lat,lon):
+        tr = None
+        for i,p in enumerate(self.points):
+            if p[0] == lat and p[1]==lon:
+                return i
+        return None
 
     def do_draw(self, gpsmap, gdkdrawable):
         if not self.drive_mode:
@@ -474,12 +481,42 @@ class google_routesearch(h_UI_helper, math_helper):
 
         if self.osmMapa.osm.props.zoom>self.zoom_minimum:
 
-
             if len( self.markers_icons ) == 0:
-                for p in self.markers:
+                markers_count = len( self.markers )-1
+                for nr, p in enumerate(self.markers):
                     if p[3] <> None:
-                        self.markers_icons.append( self.osmMapa.osm.image_add( p[0], p[1], p[3] ) )
-
+                        at_point = 0#self.get_point(p[0], p[1])
+                        at_point_back = at_point
+                        while at_point>0:
+                            p0 =  self.points[at_point]
+                            p1 =  self.points[at_point_back]
+                            
+                            dis = self.distance( p0[0],p0[1], p1[0], p1[1])
+                            
+                            if at_point_back < 0:
+                                at_point = 0
+                                break
+                            if dis < 0.01:
+                                at_point_back-=1
+                            else:
+                                if p1[0] == p0[0] or p1[1] == p0[1]:
+                                    at_point_back-=1
+                                else:
+                                    break
+                        
+                        ico_turn = p[3]
+                        if at_point and at_point >0 and markers_count > nr:
+                            angle = self.cal_angle(
+                                    self.points[at_point_back][0],
+                                    self.points[at_point_back][1],
+                                    self.points[at_point][0],
+                                    self.points[at_point][1]                                    
+                                    )[0]
+                            angle = 7-round(int(math.degrees(angle))/90)
+                            ico_turn = ico_turn.rotate_simple( (angle*90) )
+                        #self.osmMapa.osm.image_add( p[0], p[1], ico_turn )
+                        self.markers_icons.append( self.osmMapa.osm.image_add( p[0], p[1], ico_turn ) )
+            
             if self.osmMapa.get_gpslock() == 0:
 
                 t_lt, t_ln, b_lt, b_ln = self.osmMapa.osm.get_bbox()
@@ -604,8 +641,8 @@ class google_routesearch(h_UI_helper, math_helper):
                         t = int( time.strftime("%Y%m%d%H%M%S", time.localtime() ) )
 
 
-                        info = "%s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
-                        self.osmMapa.draw_cloud( cr, 50,5, info, 20, False)
+                        info = "%s %s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
+                        self.osmMapa.draw_cloud( cr, 90,0, info, 25, False, )
 
 
                         tTotal = t-self.rout_t_start
@@ -629,8 +666,8 @@ class google_routesearch(h_UI_helper, math_helper):
                         self.osmMapa.draw_cloud( cr, 150,-32-yoff, dist, 16, False)
 
                         if m[4]<> None:
-                            ico = cairo.ImageSurface.create_from_png( m[4] )
-                            cr.set_source_surface( ico, 50,65 )
+                            ico = cairo.ImageSurface.create_from_png( m[4].replace("_32_32", "_64_64") )
+                            cr.set_source_surface( ico, 70,45 )
                             cr.paint()
 
 
@@ -886,7 +923,10 @@ class google_routesearch(h_UI_helper, math_helper):
         scbox = gtk.HBox()
         scbox.pack_start( self.bt("swap",self.on_swap), False)
         scbox.pack_start( self.bt("Clear", self.on_clean), False)
-
+        hb = gtk.VBox()
+        hb.pack_start(scbox,False)
+        hb.pack_start(gtk.Label(),True)
+        scbox = hb
 
 
 
@@ -927,7 +967,7 @@ class google_routesearch(h_UI_helper, math_helper):
         hbox.pack_start( pb_mode, True )
 
         self.bt_offline = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-        self.bt_offline.set_label("work offline")
+        self.bt_offline.set_label("Work offline")
         hbox.pack_start(self.bt_offline, True)
         mvbox.pack_start( hbox, True )
 
@@ -935,20 +975,20 @@ class google_routesearch(h_UI_helper, math_helper):
 
 
         if self.espeak:
-            l = gtk.Label("espeak settings:")
-            mvbox.pack_start(l,False)
-            hbox = gtk.HBox()
-            self.bt_speak = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-            self.bt_speak.set_label("speak")
+            l = self.label("Espeak settings:")
+            mvbox.pack_start(l,True,True)
+            vboxs = gtk.VBox()
+            self.bt_speak = hildon.CheckButton(gtk.HILDON_SIZE_AUTO | gtk.HILDON_SIZE_FINGER_HEIGHT )
+            self.bt_speak.set_label("Talk to me")
             if self.CONFIG['google_routesearch_speak']:
                 self.bt_speak.set_active( True )
             self.bt_speak.connect("clicked", self.on_bt_speak)
-            hbox.pack_start(self.bt_speak, True)
+            vboxs.pack_start(self.bt_speak, True)
 
 
-            pb_lang = hildon.PickerButton(gtk.HILDON_SIZE_AUTO,
-                                        hildon.BUTTON_ARRANGEMENT_VERTICAL)
-            pb_lang.set_title("lang")
+            pb_lang = hildon.PickerButton(gtk.HILDON_SIZE_AUTO | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                        hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+            pb_lang.set_title("Language lecturer")
             selector_lang = hildon.TouchSelectorEntry(text=True)
             id = 0
             for i,lang_name in enumerate(self.espeak_langs):
@@ -958,17 +998,17 @@ class google_routesearch(h_UI_helper, math_helper):
             pb_lang.set_selector(selector_lang)
             pb_lang.set_active( id  )
             pb_lang.connect("value-changed",self.on_changed_lang, dialog)
-            hbox.pack_start( pb_lang, True )
-            mvbox.pack_start(hbox,True)
+            vboxs.pack_start( pb_lang, True )
+            mvbox.pack_start(vboxs,True)
 
 
 
-            self.bt_speak_st = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-            self.bt_speak_st.set_label("speak\nstreet names")
+            self.bt_speak_st = hildon.CheckButton(gtk.HILDON_SIZE_AUTO | gtk.HILDON_SIZE_FINGER_HEIGHT)
+            self.bt_speak_st.set_label("Speak street names")
             if self.CONFIG['google_routesearch_speak_streets_names']:
                 self.bt_speak_st.set_active( True )
             self.bt_speak_st.connect("clicked", self.on_bt_speak_st)
-            hbox.pack_start(self.bt_speak_st, True)
+            vboxs.pack_start(self.bt_speak_st, True)
 
             mvbox.pack_start(gtk.HSeparator(),True)
 
@@ -977,34 +1017,34 @@ class google_routesearch(h_UI_helper, math_helper):
             mvbox.pack_start(gtk.HSeparator(),True)
 
 
-        l = gtk.Label("auto recalculation:")
+        l = self.label("Auto recalculation route:")
         mvbox.pack_start(l,False)
-        hbox = gtk.HBox()
+        vboxa = gtk.VBox()
         #self.CONFIG['google_routesearch_auto_recal']
 
-        self.bt_recal = hildon.CheckButton(gtk.HILDON_SIZE_AUTO)
-        self.bt_recal.set_label("make it")
+        self.bt_recal = hildon.CheckButton(gtk.HILDON_SIZE_AUTO | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.bt_recal.set_label("Automatically analyze the route")
         self.bt_recal.set_active( self.CONFIG['google_routesearch_auto_recal_make'] )
         self.bt_recal.connect("clicked", self.on_bt_relac )
-        hbox.pack_start(self.bt_recal, True)
+        vboxa.pack_start(self.bt_recal, True)
 
-        pb_dis = hildon.PickerButton(gtk.HILDON_SIZE_AUTO,
-                                        hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        pb_dis.set_title("if distance is greater than [meters]")
+        pb_dis = hildon.PickerButton(gtk.HILDON_SIZE_AUTO | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                        hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+        pb_dis.set_title("Make when you're away [m]")
         selector_dis = hildon.TouchSelectorEntry(text=True)
         id = 0
-        for i in range( 100, 1600, 100 ):
+        for n,i in enumerate(range( 100, 1600, 100 )):
             selector_dis.append_text(("%s"%i))
-            if i == int(self.CONFIG['google_routesearch_auto_recal']):
+            if int(i) == int(self.CONFIG['google_routesearch_auto_recal']):
                 print "set_active",i
-                id = i
+                id = n
         pb_dis.set_selector(selector_dis)
         pb_dis.set_active( id  )
         pb_dis.connect("value-changed",self.on_changed_dis, dialog)
-        hbox.pack_start( pb_dis, True )
+        vboxa.pack_start( pb_dis, True )
 
 
-        mvbox.pack_start(hbox,True)
+        mvbox.pack_start(vboxa,True)
         mvbox.pack_start(gtk.HSeparator(),True)
 
 
