@@ -383,7 +383,8 @@ class gpx_tracks( h_UI_helper):
         if self.CONFIG['track_record']:
             self.osmMapa.osm.gps_clear()
             for p in self.osmMapa.my_gps_track:
-                self.osmMapa.gps_add( p[0],p[1],osmgpsmap.INVALID )
+                self.osmMapa.osm.gps_add( p[0],p[1] )
+                self.osmMapa.osm.gps_add( p[0],p[1],osmgpsmap.INVALID )
 
 
 
